@@ -16,10 +16,12 @@ def lineplot(
     column_title: str = "",
     column_sort: Optional[List[str]] = None,
     column_labels: bool = True,
+    column_keywords: Dict[str, Any] = {},
     row: Optional[str] = None,
     row_title: str = "",
     row_sort: Optional[List[str]] = None,
     row_labels: bool = True,
+    row_keywords: Dict[str, Any] = {},
     aggregate: Optional[str] = "mean",
     points: bool = True,
     lines: bool = True,
@@ -49,10 +51,12 @@ def lineplot(
         column_title: Title text for columns displayed 
         column_sort: Optional sorting for columns
         column_labels: Whether header labels should be displayed
+        column_keywords: Optional keywords passed to column header
         row: Shorthand for rows (optional) which are faceted
         row_title: Title text for rows displayed 
         row_sort: Optional sorting for rows
         row_labels: Whether header labels should be displayed
+        row_keywords: Optional keywords passed to row header
         aggregate: Aggregation function for y values
         points: Whether to show points
         lines: Whether to show lines
@@ -161,14 +165,14 @@ def lineplot(
             facet_kwargs["column"] = alt.Column(
                 column,
                 title=column_title,
-                header=alt.Header(labels=column_labels),
+                header=alt.Header(labels=column_labels, **column_keywords),
                 sort=column_sort,
             )
         if row is not None:
             facet_kwargs["row"] = alt.Row(
                 row,
                 title=row_title,
-                header=alt.Header(labels=row_labels),
+                header=alt.Header(labels=row_labels, **row_keywords),
                 sort=row_sort,
             )
         chart = chart.facet(**facet_kwargs)
